<?php
/*
** XRAY CMS GROUP ACCESS SETTINGS **

The constants defined in this file controls access for different user-groups.
Define a new User-Group with the syntax the others uses, only substitute the
values.

To check user access to certain functions, use function 
*  'xray_check_access("MODULE", "ACCESS");'
Where MODULE is the name of the module(POST, CAT, USER, ...), and ACCESS is the name of
the privilege required to access the feature(NEW, EDIT, DELETE, ...). ALL-privileges are checked automatically.

EXAMPLE: Check if user can write a new post:
*  'if(xray_check_access("POST", "NEW")) {...}'
This code will return true if the user is in Access Group SUPERALL, POSTALL or
POSTNEW.

To check for a certain group, use the function
* 'xray_check_group_id(GROUPID);'
Where GROUPID is the ID of the group to check for

To get the current user's Group ID, use
* 'xray_get_group();'

** NOTE! **
To assign multiple privileges to a group, use
* "access" => "PRIVILEGE1:PRIVILEGE2:PRIVILEGE3(etc...)"
Do NOT use any other separations, as that can break the group, or even the
whole system.

** WARNING! **
MAKE SURE NO TWO GROUPS HAVE THE SAME ID! IF TWO GROUPS SHARE AN ID IT CAN CREATE A MESS!
*/

/*
** GROUPS
Groups in XRAY CMS is simply names not defined anywhere explicitly, but is referred from
different checks, and follows a simple pattern.

There are two "SUPER" groups, which controls access to the whole AdminCP and all features:
SUPERALL and SUPERNONE. SUPERALL gives complete access to every feature, while SUPERNONE is
the exact reverse, No access to anything whatsoever. SUPERALL is for admins only, while SUPERNONE is for unregistered users and banned ones.
*/

//////////
// GROUP DEFINITIONS
//////////

global $group;

//Not Logged In/Banned Group(= No access)
$group[-1] = array
(
	"name" => "None",
	"access" => "SUPERNONE"
);

// Administrators, access to everything
$group[0] = array
(
	"name" => "Administrator",
	"access" => "SUPERALL"
);

// Writer, can access all post-related functions
$group[1] = array
(
	"name" => "Writer",
	"access" => "POSTALL"
);

//Moderator, can edit stuff
$group[2] = array
(
	"name" => "Moderator",
	"access" => "POSTEDIT:CATEDIT:USEREDIT:USERPASS:USERBAN"
);
?>